==> devops-client-java-1.0.6.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskArgumentDisplayFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1alpha1PipelineTaskArgumentDisplayFluent<A extends V1alpha1PipelineTaskArgumentDisplayFluent<A>> extends Fluent<A>{


    public Boolean isAdvanced();
    public A withAdvanced(Boolean advanced);
    public Boolean hasAdvanced();
    public A withNewAdvanced(String arg1);
    public A withNewAdvanced(boolean arg1);
    public A addToArgs(String key,String value);
    public A addToArgs(Map<String,String> map);
    public A removeFromArgs(String key);
    public A removeFromArgs(Map<String,String> map);
    public Map<String,String> getArgs();
    public A withArgs(Map<String,String> args);
    public Boolean hasArgs();
    
/**
 * This method has been deprecated, please use method buildDescription instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getDescription();
    public V1alpha1I18nName buildDescription();
    public A withDescription(V1alpha1I18nName description);
    public Boolean hasDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> withNewDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> withNewDescriptionLike(V1alpha1I18nName item);
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editOrNewDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editOrNewDescriptionLike(V1alpha1I18nName item);
    
/**
 * This method has been deprecated, please use method buildName instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getName();
    public V1alpha1I18nName buildName();
    public A withName(V1alpha1I18nName name);
    public Boolean hasName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> withNewName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> withNewNameLike(V1alpha1I18nName item);
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editOrNewName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editOrNewNameLike(V1alpha1I18nName item);
    public String getRelated();
    public A withRelated(String related);
    public Boolean hasRelated();
    public A withNewRelated(String arg1);
    public A withNewRelated(StringBuilder arg1);
    public A withNewRelated(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface DescriptionNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<N>>{

        
    public N and();    public N endDescription();
}
    public interface NameNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<N>>{

        
    public N and();    public N endName();
}


}

==> devops-client-java-1.0.7.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTaskArgumentDisplayFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Fluent;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface V1alpha1PipelineTaskArgumentDisplayFluent<A extends V1alpha1PipelineTaskArgumentDisplayFluent<A>> extends Fluent<A>{


    public Boolean isAdvanced();
    public A withAdvanced(Boolean advanced);
    public Boolean hasAdvanced();
    public A withNewAdvanced(String arg1);
    public A withNewAdvanced(boolean arg1);
    public A addToArgs(String key,String value);
    public A addToArgs(Map<String,String> map);
    public A removeFromArgs(String key);
    public A removeFromArgs(Map<String,String> map);
    public Map<String,String> getArgs();
    public A withArgs(Map<String,String> args);
    public Boolean hasArgs();
    
/**
 * This method has been deprecated, please use method buildDescription instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getDescription();
    public V1alpha1I18nName buildDescription();
    public A withDescription(V1alpha1I18nName description);
    public Boolean hasDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> withNewDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> withNewDescriptionLike(V1alpha1I18nName item);
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editOrNewDescription();
    public V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<A> editOrNewDescriptionLike(V1alpha1I18nName item);
    public A addToEnumAlias(int index,String item);
    public A setToEnumAlias(int index,String item);
    public A addToEnumAlias(String... items);
    public A addAllToEnumAlias(Collection<String> items);
    public A removeFromEnumAlias(String... items);
    public A removeAllFromEnumAlias(Collection<String> items);
    public List<String> getEnumAlias();
    public String getEnumAlias(int index);
    public String getFirstEnumAlias();
    public String getLastEnumAlias();
    public String getMatchingEnumAlias(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingEnumAlias(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public A withEnumAlias(List<String> enumAlias);
    public A withEnumAlias(String... enumAlias);
    public Boolean hasEnumAlias();
    public A addNewEnumAlias(String arg1);
    public A addNewEnumAlias(StringBuilder arg1);
    public A addNewEnumAlias(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildName instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getName();
    public V1alpha1I18nName buildName();
    public A withName(V1alpha1I18nName name);
    public Boolean hasName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> withNewName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> withNewNameLike(V1alpha1I18nName item);
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editOrNewName();
    public V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<A> editOrNewNameLike(V1alpha1I18nName item);
    public String getRelated();
    public A withRelated(String related);
    public Boolean hasRelated();
    public A withNewRelated(String arg1);
    public A withNewRelated(StringBuilder arg1);
    public A withNewRelated(StringBuffer arg1);
    public A addToSuggestions(int index,String item);
    public A setToSuggestions(int index,String item);
    public A addToSuggestions(String... items);
    public A addAllToSuggestions(Collection<String> items);
    public A removeFromSuggestions(String... items);
    public A removeAllFromSuggestions(Collection<String> items);
    public List<String> getSuggestions();
    public String getSuggestion(int index);
    public String getFirstSuggestion();
    public String getLastSuggestion();
    public String getMatchingSuggestion(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingSuggestion(io.alauda.devops.java.client.fluent.Predicate<String> predicate);
    public A withSuggestions(List<String> suggestions);
    public A withSuggestions(String... suggestions);
    public Boolean hasSuggestions();
    public A addNewSuggestion(String arg1);
    public A addNewSuggestion(StringBuilder arg1);
    public A addNewSuggestion(StringBuffer arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface DescriptionNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTaskArgumentDisplayFluent.DescriptionNested<N>>{

        
    public N and();    public N endDescription();
}
    public interface NameNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTaskArgumentDisplayFluent.NameNested<N>>{

        
    public N and();    public N endName();
}


}
